@@ -713,10 +713,8 @@ static gboolean _do_launch(FmAction *action, GAppLaunchContext *launch_context,
         if (term != &xterm_def)
             g_object_unref(term);
     }
-    g_debug("%s",__func__);
     if (!_expand_params(str, action->exec, action->menu, TRUE, error))
         goto finish;
-    g_debug("%s: string to execute: %s",__func__,str->str);
     if (g_shell_parse_argv(str->str, &argc, &argv, error))
     {
         FmActionMenu *menu;
